Quickstart — mosaik 2.3.1 documentation

# Quickstart

This guide assumes that you are somewhat proficient with Python and know what pip and virtualenv is. Else, you should follow the detailed instructions.

Mosaik runs on Linux, OS X and Windows. It requires Python 3.3 or higher. To install everything, you need the package manager Pip which is bundled with Python 3.4 and above.

We also strongly recommend you to install everything into a virtualenv.

You can then install mosaik with pip:

    $ pip install mosaik

This provides you with the mosaik framework. There is also a simple demo scenario which may help you to get started. Please refer to our detailed instructions for installation.